@@ -110,9 +110,8 @@ func (conn *obfs4Conn) makePacket(w io.Writer, pktType uint8, data []byte, padLe
 
 func (conn *obfs4Conn) readPackets() (err error) {
 	// Attempt to read off the network.
-	var buf [consumeReadSize]byte
-	rdLen, rdErr := conn.Conn.Read(buf[:])
-	conn.receiveBuffer.Write(buf[:rdLen])
+	rdLen, rdErr := conn.Conn.Read(conn.readBuffer)
+	conn.receiveBuffer.Write(conn.readBuffer[:rdLen])
 
 	var decoded [framing.MaximumFramePayloadLength]byte
 	for conn.receiveBuffer.Len() > 0 {
